@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2014 Red Hat, Inc.
+# Copyright (C) 2014-2016 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -57,22 +57,31 @@ def _evaluateDefaultRoute(attrs, cfg):
 
 
 def network(caps, device):
-    """Returns a dictionary that describes the network of the device"""
+    """
+    Returns a dictionary that describes the network of the device.
+    :param  caps: the output of vds_info.capabilities
+    :param  device: the name of the network device
+    :return (configuration, status): configuration is the whole dict to be
+            passed to setupNetwork to configure the bridge as needed.
+            Status is the current network status (for instance it includes
+            the IP address also if the interfaces got its address by DHCP)
+    """
     info = netinfo.NetInfo(caps)
-    attrs = {}
+    configuration = {}
+    status = {}
     if device in info.vlans:
         port_info = info.vlans[device]
-        attrs['vlan'] = port_info['vlanid']
+        configuration['vlan'] = port_info['vlanid']
         iface = port_info['iface']
         if iface in info.bondings:
-            attrs['bonding'] = iface
+            configuration['bonding'] = iface
         else:
-            attrs['nic'] = iface
+            configuration['nic'] = iface
     elif device in info.bondings:
-        attrs['bonding'] = device
+        configuration['bonding'] = device
         port_info = info.bondings[device]
     elif device in info.nics:
-        attrs['nic'] = device
+        configuration['nic'] = device
         port_info = info.nics[device]
     else:
         raise RuntimeError(
@@ -81,19 +90,28 @@ def network(caps, device):
         )
 
     if 'BOOTPROTO' in port_info['cfg']:
-        attrs['bootproto'] = port_info['cfg']['BOOTPROTO']
-    if attrs.get('bootproto') == 'dhcp':
-        attrs['blockingdhcp'] = True
+        configuration['bootproto'] = port_info['cfg']['BOOTPROTO']
+    if configuration.get('bootproto') == 'dhcp':
+        configuration['blockingdhcp'] = True
     else:
-        attrs['ipaddr'] = port_info['addr']
-        attrs['netmask'] = port_info['netmask']
+        configuration['ipaddr'] = port_info['addr']
+        configuration['netmask'] = port_info['netmask']
         gateway = port_info.get('gateway')
         if gateway is not None:
-            attrs['gateway'] = gateway
+            configuration['gateway'] = gateway
         elif 'GATEWAY' in port_info['cfg']:
-            attrs['gateway'] = port_info['cfg']['GATEWAY']
-    attrs['defaultRoute'] = _evaluateDefaultRoute(attrs, port_info['cfg'])
-    return attrs
+            configuration['gateway'] = port_info['cfg']['GATEWAY']
+    configuration['defaultRoute'] = _evaluateDefaultRoute(
+        configuration,
+        port_info['cfg']
+    )
+    if 'addr' in port_info:
+        status['ipaddr'] = port_info['addr']
+    if 'netmask' in port_info:
+        status['netmask'] = port_info['netmask']
+    if 'gateway' in port_info:
+        status['gateway'] = port_info['gateway']
+    return configuration, status
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
