@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -24,17 +24,22 @@ VM configuration plugin.
 
 
 import gettext
+import socket
+
 
-from otopi import util
-from otopi import plugin
 from otopi import constants as otopicons
+from otopi import plugin
+from otopi import util
+from vdsm import vdscli
 
 
+from ovirt_hosted_engine_setup import check_liveliness
 from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import mixins
 
 
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
 
 
 @util.export
@@ -70,8 +75,6 @@ class Plugin(mixins.VmOperations, plugin.PluginBase):
         stage=plugin.Stages.STAGE_SETUP,
     )
     def _setup(self):
-        # Can't use python api here, it will call sys.exit
-        self.command.detect('vdsClient')
         self.command.detect('remote-viewer')
 
     @plugin.event(
@@ -142,47 +145,22 @@ class Plugin(mixins.VmOperations, plugin.PluginBase):
         # Need to be done after firewall closeup for allowing the user to
         # connect from remote.
         os_installed = False
+        self._create_vm()
         while not os_installed:
-            self._create_vm()
-            response = None
-            while response is None:
-                response = self.dialog.queryString(
-                    name='OVEHOSTED_INSTALLING_OS',
-                    note=_(
-                        'The VM has been started.  Install the OS and shut '
-                        'down or reboot it.  To continue please make a '
-                        'selection:\n\n'
-                        '(1) Continue setup - VM installation is complete\n'
-                        '(2) Reboot the VM and restart installation\n'
-                        '(3) Abort setup\n'
-                        '(4) Destroy VM and abort setup\n'
-                        '\n(@VALUES@)[@DEFAULT@]: '
-                    ),
-                    prompt=True,
-                    validValues=(_('1'), _('2'), _('3'), _('4')),
-                    default=_('1'),
-                    caseSensitive=False)
-                if response == _('1').lower():
-                    self.dialog.note(
-                        _('Waiting for VM to shut down...\n')
-                    )
-                    if not self._wait_vm_destroyed():
-                        self._destroy_vm()
-                    os_installed = True
-                elif response == _('2').lower():
-                    self._destroy_vm()
-                elif response == _('3').lower():
-                    raise RuntimeError(_('OS installation aborted by user'))
-                elif response == _('4').lower():
-                    self._destroy_vm()
-                    raise RuntimeError(
-                        _('VM destroyed and setup aborted by user')
-                    )
-                else:
-                    self.logger.error(
-                        'Invalid option \'{0}\''.format(response)
-                    )
-                    response = None
+            try:
+                os_installed = check_liveliness.manualSetupDispatcher(
+                    self,
+                    check_liveliness.MSD_OS_INSTALLED,
+                )
+            except socket.error as e:
+                self.logger.debug(
+                    'Error talking with VDSM (%s), reconnecting.' % str(e),
+                    exc_info=True
+                )
+                cli = vdscli.connect(
+                    timeout=ohostedcons.Const.VDSCLI_SSL_TIMEOUT
+                )
+                self.environment[ohostedcons.VDSMEnv.VDS_CLI] = cli
 
     @plugin.event(
         stage=plugin.Stages.STAGE_CLOSEUP,
@@ -195,7 +173,30 @@ class Plugin(mixins.VmOperations, plugin.PluginBase):
         ],
     )
     def _boot_from_hd(self):
-        self._create_vm()
+        # Temporary attach cloud-init no-cloud iso if we have to
+        if (
+                self.environment[ohostedcons.VMEnv.BOOT] == 'disk' and
+                self.environment[ohostedcons.VMEnv.CDROM]
+        ):
+            self.environment[
+                ohostedcons.VMEnv.SUBST
+            ]['@CDROM@'] = self.environment[
+                ohostedcons.VMEnv.CDROM
+            ]
+        created = False
+        while not created:
+            try:
+                self._create_vm()
+                created = True
+            except socket.error as e:
+                self.logger.debug(
+                    'Error talking with VDSM (%s), reconnecting.' % str(e),
+                    exc_info=True
+                )
+                cli = vdscli.connect(
+                    timeout=ohostedcons.Const.VDSCLI_SSL_TIMEOUT
+                )
+                self.environment[ohostedcons.VDSMEnv.VDS_CLI] = cli
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
